package pps.core.base.service;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.text.CharSequenceUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.json.JSONUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import pps.core.base.entity.ConfigOilFieldEnt;
import pps.core.base.mapper.ConfigOilFieldMapper;
import pps.core.base.service.data.config_oil_field.GetConfigOilFieldOutput;
import pps.core.base.service.data.config_oil_field.GetProjectTitleOutput;
import pps.core.common.constant.BusinessConstant;
import xstartup.annotation.XService;
import xstartup.base.XContext;
import xstartup.data.XSingleResult;
import xstartup.feature.api.annotation.XApiGet;

import java.util.List;

/**
 * 油田配置模块
 *
 * @author ZWT
 * @date 2024/06/25
 */
@XService
public class ConfigOilFieldService {

    /**
     * 获取当前配置
     *
     * @param context 上下文
     * @return {@link XSingleResult }<{@link GetConfigOilFieldOutput }>
     */
    @XApiGet(anonymous = true)
    public XSingleResult<GetConfigOilFieldOutput> getCurrentConfig(XContext context) {
        ConfigOilFieldMapper mapper = context.getBean(ConfigOilFieldMapper.class);
        ConfigOilFieldEnt ent = mapper.selectOne(new LambdaQueryWrapper<ConfigOilFieldEnt>()
                .eq(ConfigOilFieldEnt::getIsEnable, BusinessConstant.ZERO)
                .last(BusinessConstant.LAST_LIMIT)
        );
        String homePagePath, title;
        if (ObjectUtil.isNull(ent)) {
            homePagePath = "/403";
            title = "零碳井场能量综合管控系统";
        } else {
            homePagePath = CharSequenceUtil.blankToDefault(ent.getHomePagePath(), "/403");
            if (JSONUtil.isTypeJSONArray(ent.getProjectTitle())) {
                List<GetProjectTitleOutput> list = JSONUtil.toList(ent.getProjectTitle(), GetProjectTitleOutput.class);
                if (CollUtil.isEmpty(list)) {
                    title = "零碳井场能量综合管控系统";
                } else {
                    title = list.stream()
                            .filter(t -> ObjectUtil.isNotNull(t.getSort()) && ObjectUtil.equals(0, t.getSort()) && CharSequenceUtil.isNotBlank(t.getTitle()))
                            .map(GetProjectTitleOutput::getTitle)
                            .findAny()
                            .orElse("零碳井场能量综合管控系统");
                }
            } else {
                title = "零碳井场能量综合管控系统";
            }
        }
        return XSingleResult.success(GetConfigOilFieldOutput.builder()
                .title(title)
                .homePagePath(homePagePath)
                .build());
    }
}